@@ -20,20 +20,14 @@
  *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 #include "sintdatainformation.h"
+#include "../poddecoder/typeeditors/sintspinbox.h"
 
 #include <QScriptValue>
 #include <KGlobal>
+#include <KLocale>
 
 template<typename T>
-QString SIntDataInformation<T>::valueString() const
-{
-    if (!mWasAbleToRead)
-        return i18nc("invalid value (out of range)", "&lt;invalid&gt;");
-    return valueString(mValue);
-}
-
-template<typename T>
-QString SIntDataInformation<T>::valueString(T val, int base)
+QString SIntDataInformationMethods<T>::staticValueString(T val, int base)
 {
     QString num;
     if (base == 10) {
@@ -93,13 +87,7 @@ QString SIntDataInformation<T>::valueString(T val, int base)
 }
 
 template<typename T>
-QScriptValue SIntDataInformation<T>::valueAsQScriptValue() const
-{
-    return asScriptValue(mValue, 0, 0);
-}
-
-template<typename T>
-QScriptValue SIntDataInformation<T>::asScriptValue(T value, QScriptEngine* engine,
+QScriptValue SIntDataInformationMethods<T>::asScriptValue(T value, QScriptEngine* engine,
         ScriptHandlerInfo* handler)
 {
     Q_UNUSED(engine);
@@ -108,7 +96,7 @@ QScriptValue SIntDataInformation<T>::asScriptValue(T value, QScriptEngine* engin
 }
 
 template<>
-QScriptValue SIntDataInformation<qint64>::asScriptValue(qint64 value, QScriptEngine* engine,
+QScriptValue SIntDataInformationMethods<qint64>::asScriptValue(qint64 value, QScriptEngine* engine,
         ScriptHandlerInfo* handler)
 {
     Q_UNUSED(engine);
@@ -117,25 +105,36 @@ QScriptValue SIntDataInformation<qint64>::asScriptValue(qint64 value, QScriptEng
 }
 
 template<typename T>
-QWidget* SIntDataInformation<T>::createEditWidget(QWidget* parent) const
+inline QWidget* SIntDataInformationMethods<T>::staticCreateEditWidget(QWidget* parent)
 {
-    return staticCreateEditWidget(parent);
+    SIntSpinBox* ret = new SIntSpinBox(parent, PrimitiveDataInformation::signedDisplayBase());
+    ret->setRange(std::numeric_limits<T>::min(), std::numeric_limits<T>::max());
+    return ret;
 }
 
 template<typename T>
-QVariant SIntDataInformation<T>::dataFromWidget(const QWidget* w) const
+inline QVariant SIntDataInformationMethods<T>::staticDataFromWidget(const QWidget* w)
 {
-    return staticDataFromWidget(w);
+    const SIntSpinBox* spin = dynamic_cast<const SIntSpinBox*>(w);
+    Q_CHECK_PTR(spin);
+    if (spin)
+        return spin->value();
+
+    kWarning() << "could not cast widget";
+    return QVariant();
 }
 
 template<typename T>
-void SIntDataInformation<T>::setWidgetData(QWidget* w) const
+inline void SIntDataInformationMethods<T>::staticSetWidgetData(T value, QWidget* w)
 {
-    staticSetWidgetData(mValue, w);
+    SIntSpinBox* spin = dynamic_cast<SIntSpinBox*>(w);
+    Q_CHECK_PTR(spin);
+    if (spin)
+        spin->setValue(value);
 }
 
 //explicitly instantiate all valid classes (c++-faq-lite 35.12)
-template class SIntDataInformation<qint8>;
-template class SIntDataInformation<qint16>;
-template class SIntDataInformation<qint32>;
-template class SIntDataInformation<qint64>;
+template class SIntDataInformationMethods<qint8>;
+template class SIntDataInformationMethods<qint16>;
+template class SIntDataInformationMethods<qint32>;
+template class SIntDataInformationMethods<qint64>;
