@@ -23,24 +23,27 @@
 
 #include "stringscriptclass.h"
 #include "../../datatypes/strings/stringdatainformation.h"
+#include "../../parsers/parserutils.h"
+
+#include <KDebug>
 
 StringScriptClass::StringScriptClass(QScriptEngine* eng, ScriptHandlerInfo* handlerInfo)
     : DefaultScriptClass(eng, handlerInfo)
 {
     //read-only properties
-    s_length = eng->toStringHandle(QLatin1String("charCount"));
-    mIterableProperties.append(qMakePair(s_length, QScriptValue::ReadOnly | QScriptValue::Undeletable));
-    s_lengthInBytes = eng->toStringHandle(QLatin1String("byteCount"));
+    s_lengthInCodepoints = eng->toStringHandle(ParserStrings::PROPERTY_CHAR_COUNT);
+    mIterableProperties.append(qMakePair(s_lengthInCodepoints, QScriptValue::ReadOnly | QScriptValue::Undeletable));
+    s_lengthInBytes = eng->toStringHandle(ParserStrings::PROPERTY_BYTE_COUNT);
     mIterableProperties.append(qMakePair(s_lengthInBytes, QScriptValue::ReadOnly | QScriptValue::Undeletable));
 
     //read-write properties
-    s_maxByteCount = eng->toStringHandle(QLatin1String("maxByteCount"));
+    s_maxByteCount = eng->toStringHandle(ParserStrings::PROPERTY_MAX_BYTE_COUNT);
     mIterableProperties.append(qMakePair(s_maxByteCount, QScriptValue::PropertyFlags(QScriptValue::Undeletable)));
-    s_maxCharCount = eng->toStringHandle(QLatin1String("maxCharCount"));
+    s_maxCharCount = eng->toStringHandle(ParserStrings::PROPERTY_MAX_CHAR_COUNT);
     mIterableProperties.append(qMakePair(s_maxCharCount, QScriptValue::PropertyFlags(QScriptValue::Undeletable)));
-    s_terminatedBy = eng->toStringHandle(QLatin1String("terminatedBy"));
+    s_terminatedBy = eng->toStringHandle(ParserStrings::PROPERTY_TERMINATED_BY);
     mIterableProperties.append(qMakePair(s_terminatedBy, QScriptValue::PropertyFlags(QScriptValue::Undeletable)));
-    s_encoding = eng->toStringHandle(QLatin1String("encoding"));
+    s_encoding = eng->toStringHandle(ParserStrings::PROPERTY_ENCODING);
     mIterableProperties.append(qMakePair(s_encoding, QScriptValue::PropertyFlags(QScriptValue::Undeletable)));
 
     mStringPrototype = eng->newObject();
@@ -58,7 +61,7 @@ bool StringScriptClass::queryAdditionalProperty(const DataInformation* data, con
     if (name == s_maxByteCount || name == s_maxCharCount || name == s_terminatedBy
             || name == s_encoding)
         return true;
-    else if (name == s_length || name == s_lengthInBytes)
+    else if (name == s_lengthInCodepoints || name == s_lengthInBytes)
     {
         *flags &= ~HandlesWriteAccess;
         return true;
@@ -97,9 +100,6 @@ QScriptValue StringScriptClass::additionalProperty(const DataInformation* data,
     if (id != 0)
     {
         quint32 pos = id - 1;
-#ifdef OKTETA_DEBUG_SCRIPT
-        kDebug() << "accessing property with id=" << id << "and name=" << name.toString();
-#endif
         if (pos >= uint(sData->stringLength()))
             return engine()->undefinedValue();
         else
@@ -107,7 +107,7 @@ QScriptValue StringScriptClass::additionalProperty(const DataInformation* data,
             return sData->valueAt(pos);
         }
     }
-    else if (name == s_length)
+    else if (name == s_lengthInCodepoints)
         return sData->stringLength();
     else if (name == s_lengthInBytes)
         return sData->stringByteLength();
@@ -128,22 +128,77 @@ bool StringScriptClass::setAdditionalProperty(DataInformation* data, const QScri
 
     if (name == s_maxCharCount)
     {
-        sData->setMaxCharCount(value, engine());
+        if (value.isNull())
+        {
+            sData->logInfo() << "Unsetting max char count.";
+            sData->unsetTerminationMode(StringData::CharCount);
+        }
+        else
+        {
+            ParsedNumber<uint> result = ParserUtils::uintFromScriptValue(value);
+            if (result.isValid)
+                sData->setMaxCharCount(result.value);
+            else
+                sData->logError() << "Could not set maximum char count, invalid argument: " << value.toString();
+        }
         return true;
     }
     else if (name == s_maxByteCount)
     {
-        sData->setMaxByteCount(value, engine());
+        if (value.isNull())
+        {
+            sData->logInfo() << "Unsetting max byte count.";
+            sData->unsetTerminationMode(StringData::ByteCount);
+        }
+        else
+        {
+            ParsedNumber<uint> result = ParserUtils::uintFromScriptValue(value);
+            if (result.isValid)
+                sData->setMaxByteCount(result.value);
+            else
+                sData->logError() << "Could not set maximum byte count, invalid argument: " << value.toString();
+        }
         return true;
     }
     else if (name == s_terminatedBy)
     {
-        sData->setTerminationCodePoint(value, engine());
+        if (value.isNull())
+        {
+            sData->logInfo() << "Unsetting termination character.";
+            sData->unsetTerminationMode(StringData::Sequence);
+        }
+        else
+        {
+            if (value.isString())
+            {
+                QString str = value.toString();
+                //we don't handle surrogate pairs, if you want to set that use a number instead.
+                if (str.length() != 1)
+                    sData->logError() << "Setting termination char: expected one char or a code point number"
+                            ", got a string with length " << str.length();
+                else
+                    sData->setTerminationCodePoint(str[0].unicode());
+            }
+            else
+            {
+                ParsedNumber<uint> result = ParserUtils::uintFromScriptValue(value);
+                if (result.isValid)
+                    sData->setTerminationCodePoint(result.value);
+                else
+                    sData->logError() << "Could not set maximum byte count, invalid argument: " << value.toString();
+            }
+        }
         return true;
     }
     else if (name == s_encoding)
     {
-        sData->setEncoding(value.toString());
+        QString enc = value.toString();
+        StringDataInformation::StringType encoding = ParserUtils::toStringEncoding(enc,
+                LoggerWithContext(sData->logger(), sData->fullObjectPath()));
+        if (encoding == StringDataInformation::InvalidEncoding)
+            sData->logError() << "Attempting to set invalid encoding:" << enc;
+        else
+            sData->setEncoding(encoding);
         return true;
     }
     return false;
@@ -162,7 +217,7 @@ QScriptValue StringScriptClass::String_proto_toString(QScriptContext* ctx, QScri
         kDebug() << "could not cast data";
         return eng->undefinedValue();
     }
-    return data->valueString();
+    return data->wasAbleToRead() ? data->valueString() : eng->undefinedValue();
 }
 
 
