@@ -26,10 +26,12 @@
 #include <klocale.h>
 
 // qt includes
-#include <QtCore/QRegExp>
+#include <QRegExp>
 
 using namespace Uml;
 
+DEBUG_REGISTER(UMLAssociation)
+
 /**
  * Sets up an association.
  * A new unique ID is assigned internally.
@@ -237,7 +239,7 @@ bool UMLAssociation::load( QDomElement & element )
                 if (m_pUMLPackage == NULL) {
                     Uml::ModelType mt = Model_Utils::convert_OT_MT(obj[r]->baseType());
                     m_pUMLPackage = doc->rootFolder(mt);
-                    uDebug() << "assoctype " << m_AssocType
+                    DEBUG(DBG_SRC) << "assoctype " << m_AssocType
                         << ": setting model type " << mt;
                 }
             }
@@ -340,7 +342,7 @@ bool UMLAssociation::load( QDomElement & element )
         if (m_pUMLPackage == NULL) {
             Uml::ModelType mt = Model_Utils::convert_OT_MT(getObject(B)->baseType());
             m_pUMLPackage = doc->rootFolder(mt);
-            uDebug() << "setting model type " << mt;
+            DEBUG(DBG_SRC) << "setting model type " << mt;
         }
 
         // setting the association type:
@@ -392,7 +394,7 @@ bool UMLAssociation::load( QDomElement & element )
                     "relationship"      // Uml::AssociationType::Relationship
         };
         const int arraySize = sizeof(assocTypeString)/sizeof(QString);
-        uDebug() << "AssociationType string array size = " << arraySize;
+        DEBUG(DBG_SRC) << "AssociationType string array size = " << arraySize;
 
         int index;
         for (index = 0; index < arraySize; ++index)
@@ -435,8 +437,8 @@ bool UMLAssociation::load( QDomElement & element )
     else
         return false;
 
-    setMulti(element.attribute( "multia", "" ), A);
-    setMulti(element.attribute( "multib", "" ), B);
+    setMultiplicity(element.attribute( "multia", "" ), A);
+    setMultiplicity(element.attribute( "multib", "" ), B);
 
     setRoleName(element.attribute( "namea", "" ), A);
     setRoleName(element.attribute( "nameb", "" ), B);
@@ -493,7 +495,7 @@ Uml::IDType UMLAssociation::getObjectId(Uml::Role_Type role) const
             uError() << "role " << role << ": getObject returns NULL";
             return Uml::id_None;
         } else {
-            uDebug() << "role " << role << ": using secondary ID " << auxID;
+            DEBUG(DBG_SRC) << "role " << role << ": using secondary ID " << auxID;
             return STR2ID(auxID);
         }
     }
@@ -531,7 +533,7 @@ Uml::Visibility UMLAssociation::getVisibility(Uml::Role_Type role) const
  * Returns the multiplicity assigned to the given role.
  * @return  The multiplicity assigned to the given role.
  */
-QString UMLAssociation::getMulti(Uml::Role_Type role) const
+QString UMLAssociation::getMultiplicity(Uml::Role_Type role) const
 {
     return m_pRole[role]->multiplicity();
 }
@@ -592,7 +594,7 @@ void UMLAssociation::setAssociationType(Uml::AssociationType assocType)
         // In this case we need to auto-set the multiplicity/rolenames
         // of the roles
 #ifdef VERBOSE_DEBUGGING
-        uDebug() << " A new uni-association has been created.";
+        DEBUG(DBG_SRC) << " A new uni-association has been created.";
 #endif
     }
     UMLObject::emitModified();
@@ -633,9 +635,9 @@ void UMLAssociation::setChangeability(Uml::Changeability value, Uml::Role_Type r
  * @param multi    The multiplicity of the given role.
  * @param role     The Uml::Role_Type to which the multiplicity is being applied
  */
-void UMLAssociation::setMulti(const QString &multi, Uml::Role_Type role)
+void UMLAssociation::setMultiplicity(const QString &multi, Uml::Role_Type role)
 {
-    UMLApp::app()->executeCommand(new CmdChangeMulti(m_pRole[role], multi));
+    UMLApp::app()->executeCommand(new CmdChangeMultiplicity(m_pRole[role], multi));
     //m_pRole[role]->setMultiplicity(multi);
 }
 
