@@ -14,7 +14,7 @@
 
 #include "codeoperation.h"
 
-#include <QtCore/QString>
+#include <QString>
 
 class DClassifierCodeDocument;
 
