@@ -19,8 +19,8 @@
 #include "operation.h"
 #include "umldoc.h"
 
-#include <QtCore/QRegExp>
-#include <QtCore/QTextStream>
+#include <QRegExp>
+#include <QTextStream>
 
 static const char *reserved_words[] = {
     "abs",
@@ -3095,7 +3095,7 @@ void Php5Writer::writeClass(UMLClassifier *c)
                 continue;
             }
             //:UNUSED: QString typeName = cleanName(o->name());
-            if (a->getMulti(Uml::A).isEmpty())  {
+            if (a->getMultiplicity(Uml::A).isEmpty())  {
                 php << m_indentation << "var $m_" << ';' << m_endl;
             } else {
                 php << m_indentation << "var $m_" << "Vector = array();" << m_endl;
@@ -3113,7 +3113,7 @@ void Php5Writer::writeClass(UMLClassifier *c)
                 continue;
             }
             //:UNUSED: QString typeName = cleanName(o->name());
-            if (a->getMulti(Uml::A).isEmpty())  {
+            if (a->getMultiplicity(Uml::A).isEmpty())  {
                 php << m_indentation << "var $m_" << ';' << m_endl;
             } else {
                 php << m_indentation << "var $m_" << "Vector = array();" << m_endl;
