@@ -45,9 +45,9 @@ FloatingTextWidgetController::~FloatingTextWidgetController()
  * Calls parent method and then saves the value of m_unconstrainedPositionX/Y
  * and m_movementDirectionX/Y.
  *
- * @param me The QMouseEvent to get the offset from.
+ * @param me The QGraphicsSceneMouseEvent to get the offset from.
  */
-void FloatingTextWidgetController::saveWidgetValues(QMouseEvent *me)
+void FloatingTextWidgetController::saveWidgetValues(QGraphicsSceneMouseEvent *me)
 {
     UMLWidgetController::saveWidgetValues(me);
 
@@ -62,10 +62,10 @@ void FloatingTextWidgetController::saveWidgetValues(QMouseEvent *me)
  * FloatingTextWidgets can't be resized, so this method always returns false.
  * Cursor isn't changed.
  *
- * @param me The QMouseEVent to check.
+ * @param me The QGraphicsSceneMouseEvent to check.
  * @return true if the mouse is in resize area, false otherwise.
  */
-bool FloatingTextWidgetController::isInResizeArea(QMouseEvent* me)
+bool FloatingTextWidgetController::isInResizeArea(QGraphicsSceneMouseEvent* me)
 {
     Q_UNUSED(me);
     return false;
@@ -90,7 +90,7 @@ bool FloatingTextWidgetController::isInResizeArea(QMouseEvent* me)
  * @param diffX The difference between current X position and new X position.
  * @param diffY The difference between current Y position and new Y position.
  */
-void FloatingTextWidgetController::moveWidgetBy(int diffX, int diffY)
+void FloatingTextWidgetController::moveWidgetBy(UMLSceneValue diffX, UMLSceneValue diffY)
 {
     if (m_floatingTextWidget->textRole() == Uml::TextRole::Seq_Message_Self)
         return;
@@ -102,7 +102,7 @@ void FloatingTextWidgetController::moveWidgetBy(int diffX, int diffY)
 
     m_unconstrainedPositionX += diffX;
     m_unconstrainedPositionY += diffY;
-    QPoint constrainedPosition = constrainPosition(diffX, diffY);
+    UMLScenePoint constrainedPosition = constrainPosition(diffX, diffY);
 
     int newX = constrainedPosition.x();
     int newY = constrainedPosition.y();
@@ -155,9 +155,9 @@ void FloatingTextWidgetController::moveWidgetBy(int diffX, int diffY)
  * @param diffX The difference between current X position and new X position.
  * @param diffY The difference between current Y position and new Y position.
  */
-void FloatingTextWidgetController::constrainMovementForAllWidgets(int &diffX, int &diffY)
+void FloatingTextWidgetController::constrainMovementForAllWidgets(UMLSceneValue &diffX, UMLSceneValue &diffY)
 {
-    QPoint constrainedPosition = constrainPosition(diffX, diffY);
+    UMLScenePoint constrainedPosition = constrainPosition(diffX, diffY);
 
     diffX = constrainedPosition.x() - m_floatingTextWidget->x();
     diffY = constrainedPosition.y() - m_floatingTextWidget->y();
@@ -173,12 +173,12 @@ void FloatingTextWidgetController::constrainMovementForAllWidgets(int &diffX, in
  *
  * @param diffX The difference between current X position and new X position.
  * @param diffY The difference between current Y position and new Y position.
- * @return A QPoint with the constrained new position.
+ * @return A UMLScenePoint with the constrained new position.
  */
-QPoint FloatingTextWidgetController::constrainPosition(int diffX, int diffY)
+UMLScenePoint FloatingTextWidgetController::constrainPosition(UMLSceneValue diffX, UMLSceneValue diffY)
 {
-    int newX = m_floatingTextWidget->x() + diffX;
-    int newY = m_floatingTextWidget->y() + diffY;
+    UMLSceneValue newX = m_floatingTextWidget->x() + diffX;
+    UMLSceneValue newY = m_floatingTextWidget->y() + diffY;
 
     if (m_floatingTextWidget->link()) {
         m_floatingTextWidget->link()->constrainTextPos(newX, newY,
@@ -186,6 +186,6 @@ QPoint FloatingTextWidgetController::constrainPosition(int diffX, int diffY)
                     m_floatingTextWidget->textRole());
     }
 
-    return QPoint(newX, newY);
+    return UMLScenePoint(newX, newY);
 }
 
