@@ -31,11 +31,13 @@
 #include <klocale.h>
 
 // qt includes
-#include <QtCore/QPointer>
-#include <QtGui/QApplication>
+#include <QApplication>
+#include <QPointer>
 
 using namespace Uml;
 
+DEBUG_REGISTER_DISABLED(UMLObject)
+
 /**
  * Creates a UMLObject.
  * @param parent   The parent of the object.
