@@ -21,7 +21,9 @@
 #include "listpopupmenu.h"
 
 // qt includes
-#include <QtGui/QPainter>
+#include <QPainter>
+
+DEBUG_REGISTER_DISABLED(FloatingDashLineWidget)
 
 /**
  * Creates a floating dash line.
@@ -45,7 +47,7 @@ FloatingDashLineWidget::~FloatingDashLineWidget()
 /**
  * Overrides the standard paint event.
  */
-void FloatingDashLineWidget::paint(QPainter & p, int /*offsetX*/, int /*offsetY*/)
+void FloatingDashLineWidget::draw(QPainter & p, int /*offsetX*/, int /*offsetY*/)
 {
     const QFontMetrics &fm = getFontMetrics(FT_NORMAL);
     const int fontHeight  = fm.lineSpacing();
@@ -71,7 +73,7 @@ void FloatingDashLineWidget::setText(const QString& text)
 /**
  * Returns true if the given point is near the floatingdashline.
  */
-bool FloatingDashLineWidget::onLine(const QPoint &point)
+bool FloatingDashLineWidget::onLine(const UMLScenePoint &point)
 {
     // check if the given point is the start or end point of the line
     if (( (abs( y() + height() - point.y() )) <= POINT_DELTA) || (abs( y() - point.y() ) <= POINT_DELTA)) {
@@ -101,7 +103,7 @@ void FloatingDashLineWidget::slotMenuSelection(QAction* action)
 /**
  * Overrides the setY method.
  */
-void FloatingDashLineWidget::setY(int y)
+void FloatingDashLineWidget::setY(UMLSceneValue y)
 {
     if(y >= m_yMin + FLOATING_DASH_LINE_MARGIN && y <= m_yMax - FLOATING_DASH_LINE_MARGIN)
         UMLWidget::setY(y);
@@ -110,7 +112,7 @@ void FloatingDashLineWidget::setY(int y)
 /**
  * Sets m_yMin.
  */
-void FloatingDashLineWidget::setYMin(int yMin)
+void FloatingDashLineWidget::setYMin(UMLSceneValue yMin)
 {
     m_yMin = yMin;
 }
@@ -118,7 +120,7 @@ void FloatingDashLineWidget::setYMin(int yMin)
 /**
  * Sets m_yMax.
  */
-void FloatingDashLineWidget::setYMax(int yMax)
+void FloatingDashLineWidget::setYMax(UMLSceneValue yMax)
 {
     m_yMax = yMax;
 }
@@ -126,7 +128,7 @@ void FloatingDashLineWidget::setYMax(int yMax)
 /**
  * Returns m_yMin.
  */
-int FloatingDashLineWidget::getYMin() const
+UMLSceneValue FloatingDashLineWidget::getYMin() const
 {
     return m_yMin;
 }
@@ -134,7 +136,7 @@ int FloatingDashLineWidget::getYMin() const
 /**
  * Returns the difference between the y-coordinate of the dash line and m_yMin.
  */
-int FloatingDashLineWidget::getDiffY() const
+UMLSceneValue FloatingDashLineWidget::getDiffY() const
 {
     return (y() - getYMin());
 }
@@ -162,12 +164,12 @@ bool FloatingDashLineWidget::loadFromXMI( QDomElement & qElement )
     if( !UMLWidget::loadFromXMI( qElement ) ) {
         return false;
     }
-    uDebug() << "load.......";
+    DEBUG(DBG_SRC) << "load.......";
     m_yMax = qElement.attribute( "maxY", "" ).toInt();
     m_yMin = qElement.attribute( "minY", "" ).toInt();
     setY(qElement.attribute( "y", "" ).toInt());
     m_Text = qElement.attribute( "text", "" );
-    uDebug() << "m_y......." << m_y;
+    DEBUG(DBG_SRC) << "m_y......." << m_y;
     return true;
 }
 
