@@ -29,7 +29,6 @@
  * @author Thomas GALLINARI <tg8187@yahoo.fr>
  * Bugs and comments to uml-devel@lists.sf.net or http://bugs.kde.org
  */
-
 class FloatingDashLineWidget : public UMLWidget
 {
     Q_OBJECT
@@ -37,19 +36,19 @@ public:
     explicit FloatingDashLineWidget(UMLScene * scene, Uml::IDType id = Uml::id_None);
     ~FloatingDashLineWidget();
 
-    void paint(QPainter & p, int offsetX, int offsetY);
+    void draw(QPainter & p, int offsetX, int offsetY);
 
     void slotMenuSelection(QAction* action);
 
-    bool onLine(const QPoint & point);
+    bool onLine(const UMLScenePoint & point);
 
     void setText(const QString& text);
 
-    void setY(int y);
-    void setYMin(int yMin);
-    void setYMax(int yMax);
-    int getYMin() const;
-    int getDiffY() const;
+    void setY(UMLSceneValue y);
+    void setYMin(UMLSceneValue yMin);
+    void setYMax(UMLSceneValue yMax);
+    UMLSceneValue getYMin() const;
+    UMLSceneValue getDiffY() const;
 
     void saveToXMI( QDomDocument & qDoc, QDomElement & qElement );
     bool loadFromXMI( QDomElement & qElement );
