@@ -34,11 +34,12 @@
 #include <klocale.h>
 
 // qt includes
-#include <QtCore/QPointer>
-#include <QtCore/QRegExp>
-#include <QtGui/QPainter>
-#include <QtGui/QValidator>
+#include <QPointer>
+#include <QRegExp>
+#include <QPainter>
+#include <QValidator>
 
+DEBUG_REGISTER_DISABLED(FloatingTextWidget)
 
 const UMLSceneValue FloatingTextWidget::restrictPositionMin = 0;
 const UMLSceneValue FloatingTextWidget::restrictPositionMax = 3000;
@@ -114,10 +115,10 @@ void FloatingTextWidget::setText(const QString &t)
         m_Text = t;
     }
 
-    QSize s = minimumSize();
+    UMLSceneSize s = minimumSize();
     setSize(s.width(), s.height());
 
-    updateComponentSize();
+    updateGeometry();
     update();
 }
 
@@ -128,7 +129,7 @@ void FloatingTextWidget::setText(const QString &t)
 void FloatingTextWidget::setPreText(const QString &t)
 {
     m_preText = t;
-    updateComponentSize();
+    updateGeometry();
     update();
 }
 
@@ -139,7 +140,7 @@ void FloatingTextWidget::setPreText(const QString &t)
 void FloatingTextWidget::setPostText(const QString &t)
 {
     m_postText = t;
-    updateComponentSize();
+    updateGeometry();
     update();
 }
 
@@ -184,12 +185,12 @@ void FloatingTextWidget::setTextcmd(const QString &t)
 void FloatingTextWidget::showChangeTextDialog()
 {
     bool ok = false;
-    QString newText = KInputDialog::getText(i18n("Change Text"), i18n("Enter new text:"), text(), &ok, m_scene->view());
+    QString newText = KInputDialog::getText(i18n("Change Text"), i18n("Enter new text:"), text(), &ok, m_scene->activeView());
 
     if (ok && newText != text() && isTextValid(newText)) {
         setText(newText);
         setVisible(!text().isEmpty());
-        updateComponentSize();
+        updateGeometry();
         update();
     }
     if (!isTextValid(newText))
@@ -212,7 +213,7 @@ void FloatingTextWidget::showOperationDialog()
         return;
     }
 
-    QPointer<SelectOpDlg> selectDlg = new SelectOpDlg(m_scene->view(), c);
+    QPointer<SelectOpDlg> selectDlg = new SelectOpDlg(m_scene->activeView(), c);
     selectDlg->setSeqNumber(seqNum);
     if (m_linkWidget->operation() == 0) {
         selectDlg->setCustomOp(opText);
@@ -377,7 +378,7 @@ void FloatingTextWidget::handleRename()
         t = i18n("ERROR");
     }
     bool ok = false;
-    QString newText = KInputDialog::getText(i18n("Rename"), t, text(), &ok, m_scene->view(), &v);
+    QString newText = KInputDialog::getText(i18n("Rename"), t, text(), &ok, m_scene->activeView(), &v);
     if (!ok || newText == text()) {
         return;
     }
@@ -437,7 +438,7 @@ void FloatingTextWidget::changeName(const QString& newText)
     }
 
     setVisible(true);
-    updateComponentSize();
+    updateGeometry();
     update();
 }
 
@@ -464,7 +465,7 @@ bool FloatingTextWidget::isTextValid(const QString &text)
 /**
  * Overrides default method
  */
-void FloatingTextWidget::paint(QPainter & p, int offsetX, int offsetY)
+void FloatingTextWidget::draw(QPainter & p, int offsetX, int offsetY)
 {
     int w = width();
     int h = height();
@@ -542,7 +543,7 @@ void FloatingTextWidget::slotMenuSelection(QAction* action)
     case ListPopupMenu::mt_Operation:
         {
             if (m_linkWidget == 0) {
-                uDebug() << "mt_Operation: m_linkWidget is NULL";
+                DEBUG(DBG_SRC) << "mt_Operation: m_linkWidget is NULL";
                 return;
             }
             UMLClassifier* c = m_linkWidget->operationOwner();
@@ -550,7 +551,7 @@ void FloatingTextWidget::slotMenuSelection(QAction* action)
                 bool ok = false;
                 QString opText = KInputDialog::getText(i18nc("operation name", "Name"),
                                                        i18n("Enter operation name:"),
-                                                       text(), &ok, m_scene->view());
+                                                       text(), &ok, m_scene->activeView());
                 if (ok)
                     m_linkWidget->setCustomOpText(opText);
                 return;
@@ -574,7 +575,7 @@ void FloatingTextWidget::slotMenuSelection(QAction* action)
     case ListPopupMenu::mt_Change_Font:
         {
             QFont fnt = font();
-            if(KFontDialog::getFont(fnt, KFontChooser::NoDisplayFlags, m_scene->view()) ) {
+            if(KFontDialog::getFont(fnt, KFontChooser::NoDisplayFlags, m_scene->activeView()) ) {
                 if(m_textRole == Uml::TextRole::Floating || m_textRole == Uml::TextRole::Seq_Message) {
                     setFont(fnt);
                 } else if (m_linkWidget) {
@@ -603,7 +604,7 @@ void FloatingTextWidget::setMessageText()
 {
     if (m_linkWidget) {
         m_linkWidget->setMessageText(this);
-        QSize s = minimumSize();
+        UMLSceneSize s = minimumSize();
         setSize(s.width(), s.height());
 
     }
