@@ -33,7 +33,7 @@ public:
     Qt::Orientation orientation() const;
     void setOrientation(Qt::Orientation ori);
 
-    virtual void paint(QPainter & p, int offsetX, int offsetY);
+    virtual void draw(QPainter & p, int offsetX, int offsetY);
 
     virtual bool loadFromXMI(QDomElement & qElement);
     virtual void saveToXMI(QDomDocument& qDoc, QDomElement& qElement);
@@ -46,7 +46,7 @@ protected:
 
     void drawSelected(QPainter * p, int offsetX, int offsetY);
 
-    void constrain(int& width, int& height);
+    void constrain(UMLSceneValue& width, UMLSceneValue& height);
 
 private:
     Qt::Orientation m_orientation;   ///< whether to draw the plate horizontally or vertically
