@@ -26,8 +26,8 @@
 #include <kdialog.h>
 
 // qt includes
-#include <QtCore/QPointer>
-#include <QtGui/QPainter>
+#include <QPainter>
+#include <QPointer>
 
 #define OBJECTNODE_MARGIN 5
 #define OBJECTNODE_WIDTH 30
@@ -57,7 +57,7 @@ ObjectNodeWidget::~ObjectNodeWidget()
 /**
  * Overrides the standard paint event.
  */
-void ObjectNodeWidget::paint(QPainter & p, int offsetX, int offsetY)
+void ObjectNodeWidget::draw(QPainter & p, int offsetX, int offsetY)
 {
     int w = width();
     int h = height();
@@ -211,7 +211,7 @@ void ObjectNodeWidget::setObjectNodeType(const QString& type)
 void ObjectNodeWidget::setState(const QString& state)
 {
     m_state = state;
-    updateComponentSize();
+    updateGeometry();
 }
 
 /**
